import React, { useEffect, useRef, useState } from 'react';
import Plot from 'react-plotly.js';
import { PreparePlot } from './MakePlot';

export const CustomChartPlotly: React.FC<{ plot: PreparePlot }> = ({ plot }) => {
  const internalRef = useRef<HTMLDivElement>(null);
  const [divSize, setDivSize] = useState({ width: 0, height: 0 });

  useEffect(() => {
    const handleResize = () => {
      if (internalRef.current) {
        const { width, height } = internalRef.current.getBoundingClientRect();
        setDivSize({ width, height });
      }
    };

    handleResize();
    window.addEventListener('resize', handleResize);
    if (internalRef.current) {
      new ResizeObserver(handleResize).observe(internalRef.current);
    }

    return () => {
      window.removeEventListener('resize', handleResize);
    };
  }, []);

  return (
    <div className="h-full w-full flex items-center justify-center overflow-hidden relative" ref={internalRef}>
      <Plot
        data={plot.plotData}
        config={{
          responsive: true,
          scrollZoom: false,
          displayModeBar: false,
          displaylogo: false,
        }}
        layout={{
          ...plot.layout,
          width: divSize.width,
          height: divSize.height,
          dragmode: false,
        }}
      />
    </div>
  );
};
