import { Vis1DInputData } from '../subPlots/types';
import { getCommonLayout, getCSSVariableHSL, sharedTickFont } from '../prepareLayout/LayoutCommon';
import { PlotType } from 'plotly.js';
import { visualizationColors } from 'ts-common';

export const preparePlotDataAndLayoutPie = (xData: Vis1DInputData, showAxis: boolean) => {
  const mainColors = visualizationColors.GPCat.colors[14];
  const counts: Record<string, number> = {};
  xData.data.forEach(val => {
    const key = String(val);
    counts[key] = (counts[key] || 0) + 1;
  });

  const labels = Object.keys(counts);
  const values = Object.values(counts);

  const data: Plotly.Data[] = [
    {
      type: 'pie' as PlotType,
      labels,
      values,
      marker: { colors: mainColors },
    },
  ];

  const layout: Partial<Plotly.Layout> = getCommonLayout({
    showAxis,
    xAxisLabel: xData.label,
    yAxisLabel: '',
    xValues: xData.data,
    yValues: [],
    plotType: 'line',
    xAxisData: xData.data,
    sortedLabels: [],
    sharedTickFont,
  });

  return { data, layout };
};
