import React, { useEffect, useRef, useState } from 'react';
import Plot from 'react-plotly.js';
import { DropdownSelector } from '@/lib/components/DropdownSelector/DropdownSelector';
import { Vis1DInputData } from './types';
import { preparePlotDataAndLayoutHistogramCount } from '../prepareData/preparePlotHistogramCount';
import { Input } from '@/lib/components/inputs';

type Vis1DHistogramCountProps = {
  xData: Vis1DInputData;
  yData: Vis1DInputData;
  zData: Vis1DInputData;
  groupByTime?: string;
  showAxis: boolean;
  stackVariable: boolean;
};

export const Vis1DHistogramCount: React.FC<Vis1DHistogramCountProps> = ({ xData, yData, zData, showAxis, groupByTime, stackVariable }) => {
  const internalRef = useRef<HTMLDivElement>(null);
  const [divSize, setDivSize] = useState({ width: 0, height: 0 });

  useEffect(() => {
    const handleResize = () => {
      if (internalRef.current) {
        const { width, height } = internalRef.current.getBoundingClientRect();
        setDivSize({ width, height });
      }
    };

    handleResize();
    window.addEventListener('resize', handleResize);
    if (internalRef.current) {
      new ResizeObserver(handleResize).observe(internalRef.current);
    }

    return () => {
      window.removeEventListener('resize', handleResize);
    };
  }, []);

  const { data, layout } = preparePlotDataAndLayoutHistogramCount(xData, yData, zData, showAxis, stackVariable, groupByTime);

  return (
    <div className="h-full w-full flex items-center justify-center overflow-hidden relative" ref={internalRef}>
      <Plot
        data={data}
        config={{
          responsive: true,
          scrollZoom: false,
          displayModeBar: false,
          displaylogo: false,
        }}
        layout={{
          ...layout,
          width: divSize.width,
          height: divSize.height,
          dragmode: false,
        }}
      />
    </div>
  );
};

interface Vis1DSettingsHistogramCountProps {
  settings: any;
  updateSettings: (updatedSettings: any) => void;
  attributeOptions: { name: string; type: string }[];
  filterYLabel: string;
  setFilterYLabel: React.Dispatch<React.SetStateAction<string>>;
  filterZLabel: string;
  setFilterZLabel: React.Dispatch<React.SetStateAction<string>>;
}

export const Vis1DSettingsHistogramCount = ({
  settings,
  updateSettings,
  attributeOptions,
  filterYLabel,
  setFilterYLabel,
  filterZLabel,
  setFilterZLabel,
}: Vis1DSettingsHistogramCountProps) => {
  return (
    <div>
      <div className="mb-2">
        {/* 
        <DropdownSelector
          label="Y Axis"
          selectedValue={settings.yAxisLabel.name}
          options={attributeOptions}
          filter={filterYLabel}
          setFilter={setFilterYLabel}
          onChange={selected => {
            updateSettings({ yAxisLabel: { name: selected.name, type: selected.type } });
          }}
        />
        */}
        <DropdownSelector
          label="Z Axis"
          selectedValue={settings.zAxisLabel.name}
          options={attributeOptions}
          filter={filterZLabel}
          setFilter={setFilterZLabel}
          onChange={selected => {
            updateSettings({ zAxisLabel: { name: selected.name, type: selected.type } });
          }}
        />
        <div className="mb-2">
          <Input type="boolean" label="Stack: " value={settings.stack} onChange={val => updateSettings({ stack: val })} />
        </div>
      </div>
    </div>
  );
};
